==> segatex-7.980.tar.gz: segatex-7.980/src/semanage_core_translation_process.h <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007-2013 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#ifndef SEMANAGECORETRANSLATIONPROCESS_H
#define SEMANAGECORETRANSLATIONPROCESS_H

#include <qdialog.h>
#include <qlayout.h>
#include <qdir.h> 
#include <qregexp.h> 
#include <qlabel.h> 
#include <q3textedit.h>
//Added by qt3to4:
#include <Q3HBoxLayout>
#include <Q3VBoxLayout>


class QLayout;
class Q3TextEdit;
class QLineEdit;
class QPushButton;
class Q3Process;

class SemanageCoreTranslationProcess: public QDialog 
{
	Q_OBJECT
public:
	SemanageCoreTranslationProcess(QWidget *parent = 0, const char *name = 0);
public slots:
signals:
protected:
private slots:
	void semanage_core_base_translation_process();
	void add_button_clicked();
	void delete_button_clicked();
	void modify_button_clicked();
	void add_button_clicked_process(QString textEdit1_str, QString textEdit2_str);
	void delete_button_clicked_process(QString textEdit3_str, QString textEdit7_str);
	void modify_button_clicked_process(QString textEdit4_str, QString textEdit5_str);
	void readFromOutputFile();
public:
private:
	QPushButton *addButton;
	QPushButton *deleteButton;
	QPushButton *modifyButton;
	QPushButton *closeButton;
	Q3TextEdit *textEdit1;

	Q3VBoxLayout *mainLayout;
	Q3VBoxLayout *upperLayout;
	Q3VBoxLayout *underLayout;
	Q3HBoxLayout *leftLayout;
	Q3HBoxLayout *rightLayout;
	Q3HBoxLayout *thirdLayout;
	Q3VBoxLayout *middleLayout;
	Q3HBoxLayout *footLayout;

        QDir dir;
        QString path;
        QString name;
        QString dir_name;
        QString forward_slash;
        QString file_interface_name;
        QString line_analized;
        QString outputfile_str;

        QStringList::Iterator it_d;
        QStringList files;

        QString radiobutton_obj_str;
        QLabel *semanageEditLabel;
        QLabel *semanageEditLabel2;
        QLabel *semanageEditLabel3;
        QLabel *semanageEditLabel4;
        QLabel *semanageEditLabel5;
        QLabel *semanageEditLabel6;
        QLabel *semanageEditLabel7;
        QLabel *semanageEditLabel8;
        QLabel *semanageEditLabel9;
        QLineEdit *semanageEditLineEdit;
        QLineEdit *semanageEditLineEdit2;
        QLineEdit *semanageEditLineEdit3;
        QLineEdit *semanageEditLineEdit4;
        QLineEdit *semanageEditLineEdit5;
        QLineEdit *semanageEditLineEdit6;
        QLineEdit *semanageEditLineEdit7;
        QLineEdit *semanageEditLineEdit8;
        QLineEdit *semanageEditLineEdit9;
        QString semanageEditLineEdit_str;
        QString semanageEditLineEdit2_str;
        QString semanageEditLineEdit3_str;
        QString semanageEditLineEdit4_str;
        QString semanageEditLineEdit5_str;
        QString semanageEditLineEdit6_str;
        QString semanageEditLineEdit7_str;
        QString semanageEditLineEdit8_str;
        QString semanageEditLineEdit9_str;
        QString semanageEditLineEdit_str_pp;
};

#endif

==> segatex-8.630.tar.gz: segatex-8.630/src/semanage_core_translation_process.h <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007-2014 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#ifndef SEMANAGECORETRANSLATIONPROCESS_H
#define SEMANAGECORETRANSLATIONPROCESS_H

#include <QDialog>
#include <QLayout>
#include <QDir> 
#include <QRegExp> 
#include <QLabel> 
#include <QTextEdit>
#include <QHBoxLayout>
#include <QVBoxLayout>

class QLayout;
class QTextEdit;
class QLineEdit;
class QPushButton;
class QProcess;

class SemanageCoreTranslationProcess: public QDialog 
{
	Q_OBJECT
public:
	SemanageCoreTranslationProcess(QWidget *parent = 0, const char *name = 0);
public slots:
signals:
protected:
private slots:
	void semanage_core_base_translation_process();
	void add_button_clicked();
	void delete_button_clicked();
	void modify_button_clicked();
	void add_button_clicked_process(QString textEdit1_str, QString textEdit2_str);
	void delete_button_clicked_process(QString textEdit3_str, QString textEdit7_str);
	void modify_button_clicked_process(QString textEdit4_str, QString textEdit5_str);
	void readFromOutputFile();
public:
private:
	QPushButton *addButton;
	QPushButton *deleteButton;
	QPushButton *modifyButton;
	QPushButton *closeButton;
	QTextEdit *textEdit1;

	QVBoxLayout *mainLayout;
	QVBoxLayout *upperLayout;
	QVBoxLayout *underLayout;
	QHBoxLayout *leftLayout;
	QHBoxLayout *rightLayout;
	QHBoxLayout *thirdLayout;
	QVBoxLayout *middleLayout;
	QHBoxLayout *footLayout;

        QDir dir;
        QString path;
        QString name;
        QString dir_name;
        QString forward_slash;
        QString file_interface_name;
        QString line_analized;
        QString outputfile_str;

        QStringList::Iterator it_d;
        QStringList files;

        QString radiobutton_obj_str;
        QLabel *semanageEditLabel;
        QLabel *semanageEditLabel2;
        QLabel *semanageEditLabel3;
        QLabel *semanageEditLabel4;
        QLabel *semanageEditLabel5;
        QLabel *semanageEditLabel6;
        QLabel *semanageEditLabel7;
        QLabel *semanageEditLabel8;
        QLabel *semanageEditLabel9;
        QLineEdit *semanageEditLineEdit;
        QLineEdit *semanageEditLineEdit2;
        QLineEdit *semanageEditLineEdit3;
        QLineEdit *semanageEditLineEdit4;
        QLineEdit *semanageEditLineEdit5;
        QLineEdit *semanageEditLineEdit6;
        QLineEdit *semanageEditLineEdit7;
        QLineEdit *semanageEditLineEdit8;
        QLineEdit *semanageEditLineEdit9;
        QString semanageEditLineEdit_str;
        QString semanageEditLineEdit2_str;
        QString semanageEditLineEdit3_str;
        QString semanageEditLineEdit4_str;
        QString semanageEditLineEdit5_str;
        QString semanageEditLineEdit6_str;
        QString semanageEditLineEdit7_str;
        QString semanageEditLineEdit8_str;
        QString semanageEditLineEdit9_str;
        QString semanageEditLineEdit_str_pp;
};

#endif
